| Title: | JHU White Matter Atlases for the 'ggseg' Ecosystem |
|---|---|
| Description: | JHU and ICBM white matter atlases for the 'ggseg' ecosystem. Includes JHU probabilistic tracts (Hua et al. 2008), ICBM-DTI-81 white matter labels (Mori et al. 2005), and ICBM tract meshes. Provides unified 'ggseg_atlas' objects with 3D mesh geometry, for use with 'ggseg3d'. |
| Authors: | Athanasia Mo Mowinckel [aut, cre] (ORCID: <https://orcid.org/0000-0002-5756-0223>), Didac Vidal-PiƱeiro [aut] (ORCID: <https://orcid.org/0000-0001-9997-9156>) |
| Maintainer: | Athanasia Mo Mowinckel <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 2.0.0 |
| Built: | 2026-05-24 06:04:50 UTC |
| Source: | https://github.com/ggsegverse/ggsegJHU |
Probabilistic white matter tract atlas based on the Johns Hopkins University DTI-based tractography.
jhu()jhu()
A ggseg.formats::ggseg_atlas object (subcortical).
Hua et al. (2008) Tract probability maps in stereotaxic spaces: analysis of white matter anatomy and tract-specific quantification. NeuroImage, 39(1):336-347 doi:10.1016/j.neuroimage.2007.07.053
jhu()jhu()
JHU probabilistic white matter tract atlas with 20 tracts,
thresholded at 25% probability. Contains 3D mesh geometry
for ggseg3d::ggseg3d().
jhu_tracts()jhu_tracts()
A ggseg.formats::ggseg_atlas object (subcortical).
Hua K, et al. (2008). Tract probability maps in stereotaxic spaces: analyses of white matter anatomy and tract-specific quantification. NeuroImage, 39(1):336-347. doi:10.1016/j.neuroimage.2007.07.053
Other ggseg_atlases:
jhu_wm()
Other tract_atlases:
jhu_wm()
jhu_tracts()jhu_tracts()
White matter label atlases derived from the ICBM DTI-81 probabilistic atlas of 81 normal subjects.
jhu_wm() icbm()jhu_wm() icbm()
jhu_wm() provides the full 48-region atlas with both 2D and
3D geometry. icbm() is a legacy variant with 3D geometry only.
A ggseg.formats::ggseg_atlas object (subcortical).
Mori S, et al. (2005). MRI Atlas of Human White Matter. Elsevier. ISBN: 978-0444517418
Wakana S, et al. (2007). Reproducibility of quantitative tractography methods applied to cerebral white matter. NeuroImage, 36(3):630-644. doi:10.1016/j.neuroimage.2007.02.049
Other ggseg_atlases:
jhu_tracts()
Other tract_atlases:
jhu_tracts()
jhu_wm() icbm()jhu_wm() icbm()